==> owncloud-8.1.0p2.tgz: owncloud/apps/files_external/l10n/sr.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "Преузимање тражених токена није успело. Проверите  да ли су Dropbox апликациони кључ и тајна тачни.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "Преузимање приступних токена није успело. Проверите  да ли су Dropbox апликациони кључ и тајна тачни.",
    "Please provide a valid Dropbox app key and secret." : "Унесите исправан кључ и тајну за Дропбокс апликацију.",
    "Step 1 failed. Exception: %s" : "Корак 1 није успео. Изузетак: %s",
    "Step 2 failed. Exception: %s" : "Корак 2 није успео. Изузетак: %s",
    "External storage" : "Спољашње складиште",
    "Local" : "локална",
    "Location" : "Локација",
    "Amazon S3" : "Амазон С3",
    "Key" : "Кључ",
    "Secret" : "Тајна",
    "Bucket" : "Канта",
    "Amazon S3 and compliant" : "Амазон С3 и одговарајући",
    "Access Key" : "Приступни кључ",
    "Secret Key" : "Тајни кључ",
    "Hostname" : "Име домаћина",
    "Port" : "Порт",
    "Region" : "Регија",
    "Enable SSL" : "Омогући ССЛ",
    "Enable Path Style" : "Омогући стил путање",
    "App key" : "Кључ апликације",
    "App secret" : "Тајна апликације",
    "Host" : "Домаћин",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Remote subfolder" : "Удаљена потфасцикла",
    "Secure ftps://" : "Сигурни ftps://",
    "Client ID" : "ИД клијента",
    "Client secret" : "Тајна клијента",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Region (optional for OpenStack Object Storage)" : "Регион (није обавезно за OpenStack Object Storage)",
    "API Key (required for Rackspace Cloud Files)" : "API Key (потребан за Rackspace Cloud Files)",
    "Tenantname (required for OpenStack Object Storage)" : "Tenantname (потребно за OpenStack Object Storage)",
    "Password (required for OpenStack Object Storage)" : "Лозинка (потребна за OpenStack Object Storage)",
    "Service Name (required for OpenStack Object Storage)" : "Име сервиса (потребно за OpenStack Object Storage)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "Адреса идентитета крајње тачке (потребно за OpenStack Object Storage)",
    "Timeout of HTTP requests in seconds" : "Време истека ХТТП захтева у секундама",
    "Share" : "Дели",
    "SMB / CIFS using OC login" : "СМБ/ЦИФС користећи оунКлауд пријаву",
    "Username as share" : "Корисничко име као дељење",
    "URL" : "УРЛ",
    "Secure https://" : "Сигурни https://",
    "SFTP with secret key login" : "СФТП са пријавом помоћу тајног кључа",
    "Public key" : "Јавни кључ",
    "Storage with id \"%i\" not found" : "Складиште са идентификацијом \"%i\" није пронађено",
    "Invalid mount point" : "Неисправна тачка монтирања",
    "Invalid storage backend \"%s\"" : "Неисправна позадина складишта „%s“",
    "Access granted" : "Приступ одобрен",
    "Error configuring Dropbox storage" : "Грешка при подешавању Дропбокс складишта",
    "Grant access" : "Одобри приступ",
    "Error configuring Google Drive storage" : "Грешка при подешавању Гугл диск складишта",
    "Personal" : "Лично",
    "System" : "Систем",
    "Enable encryption" : "Укључи шифровање",
    "Enable previews" : "Укључи прегледе",
    "Check for changes" : "Провери измене",
    "Never" : "никад",
    "Once every direct access" : "једном при сваком директном приступу",
    "Every time the filesystem is used" : "сваки пут кад се фајл-систем користи",
    "All users. Type to select user or group." : "Сви корисници. Куцајте за избор корисника или групе.",
    "(group)" : "(група)",
    "Saved" : "Сачувано",
    "Generate keys" : "Генериши кључеве",
    "Error generating key pair" : "Грешка при генерисању пара кључева",
    "<b>Note:</b> " : "<b>Напомена:</b> ",
    "and" : "и",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> cURL подршка за ПХП није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> ФТП подршка за ПХП није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> „%s“ није инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "No external storage configured" : "Нема подешеног спољашњег складишта",
    "You can add external storages in the personal settings" : "Можете додати спољна складишта у вашим личним подешавањима",
    "Name" : "Назив",
    "Storage type" : "Тип складишта",
    "Scope" : "Распон",
    "External Storage" : "Спољашње складиште",
    "Folder name" : "Назив фасцикле",
    "Configuration" : "Подешавање",
    "Available for" : "Доступно за",
    "Add storage" : "Додај складиште",
    "Advanced settings" : "Напредне поставке",
    "Delete" : "Обриши",
    "Enable User External Storage" : "Укључи корисничко спољашње складиште",
    "Allow users to mount the following external storage" : "Дозволи корисницима да монтирају следећа спољашња складишта"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_external/l10n/sr.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Корак 1 није успео. Изузетак: %s",
    "Step 2 failed. Exception: %s" : "Корак 2 није успео. Изузетак: %s",
    "External storage" : "Спољашње складиште",
    "Personal" : "Лично",
    "System" : "Систем",
    "Grant access" : "Одобри приступ",
    "Generate keys" : "Генериши кључеве",
    "Error generating key pair" : "Грешка при генерисању пара кључева",
    "All users. Type to select user or group." : "Сви корисници. Куцајте за избор корисника или групе.",
    "(group)" : "(група)",
    "Saved" : "Сачувано",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Save" : "Сачувај",
    "Storage with id \"%i\" not found" : "Складиште са идентификацијом \"%i\" није пронађено",
    "Invalid mount point" : "Неисправна тачка монтирања",
    "Invalid storage backend \"%s\"" : "Неисправна позадина складишта „%s“",
    "App key" : "Кључ апликације",
    "App secret" : "Тајна апликације",
    "Client ID" : "ИД клијента",
    "Client secret" : "Тајна клијента",
    "API key" : "API кључ",
    "Public key" : "Јавни кључ",
    "Amazon S3" : "Амазон С3",
    "Bucket" : "Канта",
    "Hostname" : "Име домаћина",
    "Port" : "Порт",
    "Region" : "Регија",
    "Enable SSL" : "Омогући ССЛ",
    "Enable Path Style" : "Омогући стил путање",
    "WebDAV" : "ВебДАВ",
    "URL" : "УРЛ",
    "Remote subfolder" : "Удаљена потфасцикла",
    "Secure https://" : "Сигурни https://",
    "Dropbox" : "Dropbox",
    "Local" : "локална",
    "Location" : "Локација",
    "ownCloud" : "оунКлауд",
    "SFTP" : "СФТП",
    "Host" : "Домаћин",
    "Root" : "Корен",
    "SFTP with secret key login" : "СФТП са пријавом помоћу тајног кључа",
    "SMB / CIFS" : "ЦМБ/ЦИФС",
    "Share" : "Дели",
    "Domain" : "Домен",
    "SMB / CIFS using OC login" : "СМБ/ЦИФС користећи оунКлауд пријаву",
    "Username as share" : "Корисничко име као дељење",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Назив услуге",
    "<b>Note:</b> " : "<b>Напомена:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> cURL подршка за ПХП није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Напомена:</b> „%s“ није инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "No external storage configured" : "Нема подешеног спољашњег складишта",
    "Name" : "Назив",
    "Storage type" : "Тип складишта",
    "Scope" : "Распон",
    "Enable encryption" : "Укључи шифровање",
    "Enable previews" : "Укључи прегледе",
    "Enable sharing" : "Укључи дељење",
    "Check for changes" : "Провери измене",
    "Never" : "никад",
    "Once every direct access" : "једном при сваком директном приступу",
    "External Storage" : "Спољашње складиште",
    "Folder name" : "Назив фасцикле",
    "Authentication" : "Аутентификација",
    "Configuration" : "Подешавање",
    "Available for" : "Доступно за",
    "Add storage" : "Додај складиште",
    "Advanced settings" : "Напредне поставке",
    "Delete" : "Обриши",
    "Allow users to mount the following external storage" : "Дозволи корисницима да монтирају следећа спољашња складишта"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
